#ifndef NT2_INCLUDE_FUNCTIONS_PPVAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PPVAL_HPP_INCLUDED

#include <nt2/interpol/include/functions/ppval.hpp>

#endif
